CustomTable class

Inheritance

Constructors

CustomTable({double? tableHeight = 30.0, double? height, int? tableMarge, Widget? margeContent, required List tableTitle, Axis? tableAxis = Axis.vertical, List? horizontalTableContent, List? verticalTableContent})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double?
表格高度
final
horizontalTableContent → List?
需要水平方向的表格内容
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margeContent → Widget?
合并单元格内的内容
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableAxis → Axis?
合并单元格的方向
final
tableHeight → double?
单个单元格高度
final
tableMarge → int?
合并单元格下标
final
tableTitle → List
表格的title
final
verticalTableContent → List?
需要垂直方向的表格内容
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited